import argparse
import sys

import boto3

from instance_selector import InstanceSelector


def print_troubleshooting_steps():
    # fmt: off
    print("Troubleshooting steps:")
    print("1. Check if the SSM agent is installed and running on the instance.")
    print("2. Check if the instance is reachable and has an appropriate security group attached.") # noqa
    print("3. Verify that the IAM instance profile attached to the instance has the required permissions to use SSM.") # noqa
    print("4. Verify that the session manager plugin is installed on your local machine.") # noqa
    # fmt: on


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("--profile", "-p", help="AWS profile name", default=None)
    args = parser.parse_args()

    region_name = "ap-northeast-1"
    session = (
        boto3.Session(profile_name=args.profile) if args.profile else boto3.Session()
    )
    region_name = session.region_name

    selector = InstanceSelector(region_name=region_name)
    instance_id = selector.select_instance()

    if instance_id is None:
        sys.exit(0)

    ssm_client = session.client("ssm", region_name=region_name)

    try:
        response = ssm_client.start_session(Target=instance_id)
    except ssm_client.exceptions.TargetNotConnected:
        print(f"Failed to start SSM session on instance {instance_id}")
        print_troubleshooting_steps()
        sys.exit(1)

    session_id = response["SessionId"]
    print(f"Started SSM Session with SessionId: {session_id}")


if __name__ == "__main__":
    main()
